/* Make data for matlab */

set more off
clear all
set mem 1500m
set matsize 10000
set maxvar 10000

/* Long Term Care */

* LTC Covariates *
global ltcagegender = "agegender_* "
global ltccovariatesfull = " agegender_* group1_* numconditionsagecat1_* numconditionsagecat2_* numadlagerej_* famcat_* homcarage_* agereg_* ageinc_* " 
global ltccovariatesprice = " pricegroup_* " 

global ltccovariatesmat = "age agesq female agefemale agesqfemale lowword i_adl_num psych diab lung arthr heart cancr stroke hibp "

* Reject Sample
use data/hrs_using_ltc_sample, clear
keep if reject_ltc == 1 

_rmcoll $ltccovariatesmat , forcedrop
global cov_use `r(varlist)'
egen indid_n = group(hhidpn)
egen hhid_n = group(hhid)
keep indid_n hhid_n nrshom5y selfprob5y reject_ltc $cov_use
order indid_n hhid_n nrshom5y selfprob5y reject_ltc $cov_use
save matlab/using_matlab_ltc_r , replace

* No Reject Sample
use data/hrs_using_ltc_sample, clear
keep if reject_ltc == 0 

_rmcoll $ltccovariatesmat , forcedrop
global cov_use `r(varlist)'
egen indid_n = group(hhidpn)
egen hhid_n = group(hhid)
keep indid_n hhid_n nrshom5y selfprob5y reject_ltc $cov_use
order indid_n hhid_n nrshom5y selfprob5y reject_ltc $cov_use
save matlab/using_matlab_ltc_nr , replace

* Uncertain Sample
use data/hrs_using_ltc_sample, clear
keep if reject_ltc == 2 

_rmcoll $ltccovariatesmat , forcedrop
global cov_use `r(varlist)'
egen indid_n = group(hhidpn)
egen hhid_n = group(hhid)
keep indid_n hhid_n nrshom5y selfprob5y reject_ltc $cov_use
order indid_n hhid_n nrshom5y selfprob5y reject_ltc $cov_use
save matlab/using_matlab_ltc_u , replace

/*

keep if reject_ltc ~=2
*keep if sp1l ~=.
keep indid_n hhid_n nrshom5y selfprob5y reject_ltc $cov_use
order indid_n hhid_n nrshom5y selfprob5y reject_ltc $cov_use
outsheet using matlab/using_matlab_ltc.csv , comma replace
save matlab/using_matlab_ltc , replace
keep indid_n hhid_n nrshom5y selfprob5y reject_ltc 
outsheet using matlab/using_matlab_ltc_small.csv, comma replace

/* Long term care - age 80 sample */

use data/hrs_using_ltc_sample, clear
egen indid_n = group(hhidpn)
egen hhid_n = group(hhid)
keep if age <= 95
keep if age >= 65
gen aget = (age - 80) / 30
keep if reject == 0
*keep if sp1l ~=.

keep indid_n hhid_n nrshom5y selfprob5y reject_ltc aget $cov_use


order indid_n hhid_n nrshom5y selfprob5y reject_ltc aget $cov_use
outsheet using matlab/using_matlab_ltc_age.csv , comma replace
*/


/* Disability */



global disagegender = "agegender_* "
global discovariatesfull = " agegender_* jobchar_* jobdiff_* backgroup_* psychegroup_* cancrgroup_* diabgroup_* lunggroup_* arthrgroup_* bmigroup_* heartgroup_* agereg_* "
global discovariatesprice = "agegender_* jobchar_* back_r_* psych_r_* cancr_r_* diab_r_* lung_r_* arthr_r_* heart_r_*  "
global dissubj_s = " worklm worklm2 worklm3 "

global dissubj = "pdc*"

global discovariatesmat = "age agesq female agefemale agesqfemale slfemp obese psych back wagecat_* diab lung arthr heart cancr stroke hibp bmi "

* Reject Sample
use data/hrs_using_dis_sample, clear
keep if reject_dis == 1 
_rmcoll $discovariatesmat , forcedrop
global cov_use `r(varlist)'
egen indid_n = group(hhidpn)
egen hhid_n = group(hhid)
keep indid_n hhid_n hlthlm_r5f worklm reject_dis $cov_use
order indid_n hhid_n hlthlm_r5f worklm reject_dis $cov_use
save matlab/using_matlab_dis_r, replace

* No Reject Sample
use data/hrs_using_dis_sample, clear
keep if reject_dis == 0 
_rmcoll $discovariatesmat , forcedrop
global cov_use `r(varlist)'
egen indid_n = group(hhidpn)
egen hhid_n = group(hhid)
keep indid_n hhid_n hlthlm_r5f worklm reject_dis $cov_use
order indid_n hhid_n hlthlm_r5f worklm reject_dis $cov_use
save matlab/using_matlab_dis_nr, replace

* Uncertain Sample
use data/hrs_using_dis_sample, clear
keep if reject_dis == 2 
_rmcoll $discovariatesmat , forcedrop
global cov_use `r(varlist)'
egen indid_n = group(hhidpn)
egen hhid_n = group(hhid)
keep indid_n hhid_n hlthlm_r5f worklm reject_dis $cov_use
order indid_n hhid_n hlthlm_r5f worklm reject_dis $cov_use
save matlab/using_matlab_dis_u, replace


* No Reject Sample - alternative definition
use data/hrs_using_dis_sample, clear
keep if reject_dis == 0 
keep if anyADL == 0
keep if hibpe == 0
_rmcoll $discovariatesmat , forcedrop
global cov_use `r(varlist)'
egen indid_n = group(hhidpn)
egen hhid_n = group(hhid)
keep indid_n hhid_n hlthlm_r5f worklm reject_dis $cov_use
order indid_n hhid_n hlthlm_r5f worklm reject_dis $cov_use
save matlab/using_matlab_dis_nra, replace


* No Reject Sample - alternative definition with low income
use data/hrs_using_dis_sample, clear
keep if reject_dis_ni == 0 
_rmcoll $discovariatesmat , forcedrop
global cov_use `r(varlist)'
egen indid_n = group(hhidpn)
egen hhid_n = group(hhid)
keep indid_n hhid_n hlthlm_r5f worklm reject_dis_ni $cov_use
order indid_n hhid_n hlthlm_r5f worklm reject_dis_ni $cov_use
save matlab/using_matlab_dis_nri, replace


/* Life */

global lifecovariatesmat = "age agesq female agefemale agesqfemale smoken bmi psych diab lung arthr heart cancr stroke hibp incomecat_* yearsquestion_* parentb460"
global annuitycovmat = "age agesq female agefemale agesqfemale "

* Reject Sample
use data/hrs_using_life_sample, clear
keep if reject_life == 1
_rmcoll $lifecovariatesmat , forcedrop
global cov_use `r(varlist)'
egen indid_n = group(hhidpn)
egen hhid_n = group(hhid)
keep indid_n hhid_n dead dieprob reject_life $cov_use
order indid_n hhid_n dead dieprob reject_life $cov_use
save matlab/using_matlab_life_r, replace


* No Reject Sample
use data/hrs_using_life_sample, clear
keep if reject_life == 0
_rmcoll $lifecovariatesmat , forcedrop
global cov_use `r(varlist)'
egen indid_n = group(hhidpn)
egen hhid_n = group(hhid)

keep indid_n hhid_n dead dieprob reject_life $cov_use
order indid_n hhid_n dead dieprob reject_life $cov_use
save matlab/using_matlab_life_nr, replace


* Uncertain Sample
use data/hrs_using_life_sample, clear
keep if reject_life == 2
_rmcoll $lifecovariatesmat , forcedrop
global cov_use `r(varlist)'
egen indid_n = group(hhidpn)
egen hhid_n = group(hhid)
keep indid_n hhid_n dead dieprob reject_life $cov_use
order indid_n hhid_n dead dieprob reject_life $cov_use
save matlab/using_matlab_life_u, replace


* Annuity Sample
use data/hrs_using_life_sample, clear

_rmcoll $annuitycovmat , forcedrop
global cov_use `r(varlist)'
egen indid_n = group(hhidpn)
egen hhid_n = group(hhid)
keep indid_n hhid_n dead dieprob reject_life $cov_use
order indid_n hhid_n dead dieprob reject_life $cov_use
save matlab/using_matlab_annuity, replace
